..
   This file is part of the shibboleth-authenticator module for Invenio.
   Copyright (C) 2017  Helmholtz-Zentrum Dresden-Rossendorf

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
..

.. include:: ../../README.rst
  :end-before: Developer documentation

Contents
--------

.. toctree::
   :maxdepth: 2

User's Guide
------------

This part of the documentation will show you how to get started in using
Shibboleth-Authenticator module for Invenio.

.. toctree::
   :maxdepth: 2

   installation
   usage

API Reference
-------------

If you look for information on a specific function, class or method,
this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api
